# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"TEST_IMAGE": "00_core.ipynb",
         "zip_safe": "00_core.ipynb",
         "wmean": "00_core.ipynb",
         "create": "00_core.ipynb",
         "IncrementalSplitter": "01_data.ipynb",
         "coco_stats": "01_data.ipynb",
         "TensorImageX": "01_data.ipynb",
         "PILImageX": "01_data.ipynb",
         "NormalizeX": "01_data.ipynb",
         "style_blocks": "01_data.ipynb",
         "NormalizeAll": "01_data.ipynb",
         "prepare_feat_model": "02_layer_features.ipynb",
         "get_layers": "02_layer_features.ipynb",
         "FeatModels": "02_layer_features.ipynb",
         "LayerFeats": "02_layer_features.ipynb",
         "gram": "03_loss.ipynb",
         "ContentLoss": "03_loss.ipynb",
         "content_loss": "03_loss.ipynb",
         "StyleLoss": "03_loss.ipynb",
         "TVLoss": "03_loss.ipynb",
         "PixelLoss": "03_loss.ipynb",
         "pixel_loss": "03_loss.ipynb",
         "FastStyleLoss": "03_loss.ipynb",
         "SuperResLoss": "03_loss.ipynb",
         "style_learner": "04_learner.ipynb",
         "transformer_net": "04_models.ipynb",
         "TransformerNet": "04_models.ipynb",
         "FeatsCallback": "06_callback.ipynb"}

modules = ["core.py",
           "data.py",
           "layer_features.py",
           "loss.py",
           "learner.py",
           "models.py",
           "callback.py"]

doc_url = "https://lgvaz.github.io/faststyle/"

git_url = "https://github.com/lgvaz/faststyle/tree/master/"

def custom_doc_links(name): return None
